# Changelog

## Version 0.4.0

  * Updated to laspy 2.0
  * Added lazrs to requirements
  * Fixed a bug where existing task cache was getting overwritten [#2](https://github.com/hobu/ept-python/issues/2)
  * Added version limits to requirements
  * Minor PEP8 style changes
